@@ -1,4 +1,5 @@
 import os
+import time
 import json
 from dsmr_parser import telegram_specifications
 from dsmr_parser.clients import SerialReader, SERIAL_SETTINGS_V2_2
@@ -217,25 +218,28 @@ class DSMRReader():
         # self.devices = [DSMREntity(name, obis) for name, obis in self.obis_mapping]
         self.devices = [DSMREntity(name, obis) for name, obis in self.obis_mapping_json]
 
-    def format_telegram(self, telegram):
+    def extract_data_from_telegram(self, telegram):
       '''
       Transform telegram to json
       '''
-      body = dict(
-        current_electricity_usage = float(telegram[obis_ref.CURRENT_ELECTRICITY_USAGE].value),
-        current_electricity_delivery = float(telegram[obis_ref.CURRENT_ELECTRICITY_DELIVERY].value),
-        electricity_active_tariff = int(telegram[obis_ref.ELECTRICITY_ACTIVE_TARIFF].value),
-        electricity_used_tariff_1 = float(telegram[obis_ref.ELECTRICITY_USED_TARIFF_1].value),
-        electricity_used_tariff_2 = float(telegram[obis_ref.ELECTRICITY_USED_TARIFF_2].value),
-        electricity_delivered_tariff_1 = float(telegram[obis_ref.ELECTRICITY_DELIVERED_TARIFF_1].value),
-        electricity_delivered_tariff_2 = float(telegram[obis_ref.ELECTRICITY_DELIVERED_TARIFF_2].value),
-        gas_meter_reading = float(telegram[obis_ref.GAS_METER_READING].value)
+      # solar = self.read_solar()
+
+      data = dict(
+        unix_timestamp = int(time.time()),
+        current_electricity_usage = str(telegram[obis_references.CURRENT_ELECTRICITY_USAGE].value * 1000),
+        current_electricity_delivery = str(telegram[obis_references.CURRENT_ELECTRICITY_DELIVERY].value * 1000),
+        electricity_active_tariff = str(telegram[obis_references.ELECTRICITY_ACTIVE_TARIFF].value),
+        usage_total_low = str(telegram[obis_references.ELECTRICITY_USED_TARIFF_1].value * 1000),
+        usage_total_high = str(telegram[obis_references.ELECTRICITY_USED_TARIFF_2].value * 1000),
+        redelivery_total_low = str(telegram[obis_references.ELECTRICITY_DELIVERED_TARIFF_1].value * 1000),
+        redelivery_total_high = str(telegram[obis_references.ELECTRICITY_DELIVERED_TARIFF_2].value * 1000),
+        usage_gas_total = str(telegram[obis_references.HOURLY_GAS_METER_READING].value * 1000)
       )
 
-      if self.device:
-          print(body)
+      if self.debug:
+          print(json.dumps(data, indent=2))
 
-      return json.dumps(body)
+      return data
 
     def __update_entities_telegram(self, telegram):
         '''
@@ -258,7 +262,7 @@ class DSMRReader():
 
           for telegram in self.serial_reader.read_as_object():
             # now, translate telegram to dict
-            obj = self.format_telegram(telegram)
+            obj = self.extract_data_from_telegram(telegram)
 
             # do something with 'obj'
             
